# Pipeteer

> Queue-based workflow orchestration

## Ideas of v3
- Pass parameters on queue creation instead of (or both) on running?
  - So that one e.g. can override `push_queue` and `premap` it by storing an image or something